@@ -15,19 +15,19 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 9
+#define ARROW_VERSION_MAJOR 10
 #define ARROW_VERSION_MINOR 0
-#define ARROW_VERSION_PATCH 0
+#define ARROW_VERSION_PATCH 1
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "9.0.0"
+#define ARROW_VERSION_STRING "10.0.1"
 
-#define ARROW_SO_VERSION "900"
-#define ARROW_FULL_SO_VERSION "900.0.0"
+#define ARROW_SO_VERSION "1000"
+#define ARROW_FULL_SO_VERSION "1000.1.0"
 
 #define ARROW_CXX_COMPILER_ID "Clang"
 #define ARROW_CXX_COMPILER_VERSION "14.0.6"
-#define ARROW_CXX_COMPILER_FLAGS "-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Qunused-arguments -fcolor-diagnostics -O3 -DNDEBUG"
+#define ARROW_CXX_COMPILER_FLAGS "-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Qunused-arguments -fcolor-diagnostics -O2 -DNDEBUG"
 
 #define ARROW_BUILD_TYPE "RELEASE"
 
@@ -42,14 +42,19 @@
 #define ARROW_DATASET
 #define ARROW_FILESYSTEM
 #define ARROW_FLIGHT
+#define ARROW_FLIGHT_SQL
 #define ARROW_IPC
 #define ARROW_JEMALLOC
 #define ARROW_JEMALLOC_VENDORED
 #define ARROW_JSON
+#define ARROW_ORC
+#define ARROW_PARQUET
+#define ARROW_SUBSTRAIT
 
 /* #undef ARROW_GCS */
 /* #undef ARROW_S3 */
 #define ARROW_USE_NATIVE_INT128
+/* #undef ARROW_WITH_MUSL */
 /* #undef ARROW_WITH_OPENTELEMETRY */
 /* #undef ARROW_WITH_UCX */
 
